==> halloy-2025.4.tar.gz: halloy-2025.4/book/src/README.md <==
# Halloy

<img src="images/banner-logo.png" style="width: 100%">

![halloy](./images/animation.gif)

**Halloy** is an open-source IRC client written in Rust, with the [iced](https://github.com/iced-rs/iced/) GUI library. It aims to provide a simple and fast client for Mac, Windows, and Linux platforms.

* IRCv3.2 capabilities
    * [account-notify](https://ircv3.net/specs/extensions/account-notify)
    * [away-notify](https://ircv3.net/specs/extensions/away-notify)
    * [batch](https://ircv3.net/specs/extensions/batch)
    * [cap-notify](https://ircv3.net/specs/extensions/capability-negotiation.html#cap-notify)
    * [chathistory](https://ircv3.net/specs/extensions/chathistory)
    * [chghost](https://ircv3.net/specs/extensions/chghost)
    * [echo-message](https://ircv3.net/specs/extensions/echo-message)
    * [extended-join](https://ircv3.net/specs/extensions/extended-join)
    * [invite-notify](https://ircv3.net/specs/extensions/invite-notify)
    * [labeled-response](https://ircv3.net/specs/extensions/labeled-response)
    * [message-tags](https://ircv3.net/specs/extensions/message-tags)
    * [Monitor](https://ircv3.net/specs/extensions/monitor)
    * [msgid](https://ircv3.net/specs/extensions/message-ids)
    * [multi-prefix](https://ircv3.net/specs/extensions/multi-prefix)
    * [read-marker](https://ircv3.net/specs/extensions/read-marker)
    * [sasl-3.1](https://ircv3.net/specs/extensions/sasl-3.1)
    * [server-time](https://ircv3.net/specs/extensions/server-time)
    * [setname](https://ircv3.net/specs/extensions/setname.html)
    * [Standard Replies](https://ircv3.net/specs/extensions/standard-replies)
    * [userhost-in-names](https://ircv3.net/specs/extensions/userhost-in-names)
    * [`UTF8ONLY`](https://ircv3.net/specs/extensions/utf8-only)
    * [`WHOX`](https://ircv3.net/specs/extensions/whox)
* SASL support
* DCC Send
* Keyboard shortcuts
* Auto-completion for nicknames, commands, and channels
* Notifications support
* Multiple channels at the same time across servers
* Commandbar for for quick actions
* [Custom themes](https://themes.halloy.chat)
* Portable mode

## Contributing
Halloy is free and open source. You can find the source code as well as report issues and feature requests on [GitHub](https://github.com/squidowl/halloy).

==> halloy-2025.9.tar.gz: halloy-2025.9/book/src/README.md <==
# Halloy

<img src="images/banner.png" style="width: 100%">

![halloy](./images/animation.gif)

**Halloy** is an open-source IRC client written in Rust, with the [iced](https://github.com/iced-rs/iced/) GUI library. It aims to provide a simple and fast client for Mac, Windows, and Linux platforms.

* IRCv3.2 capabilities
    * [account-notify](https://ircv3.net/specs/extensions/account-notify)
    * [away-notify](https://ircv3.net/specs/extensions/away-notify)
    * [batch](https://ircv3.net/specs/extensions/batch)
    * [cap-notify](https://ircv3.net/specs/extensions/capability-negotiation.html#cap-notify)
    * [chathistory](https://ircv3.net/specs/extensions/chathistory)
    * [chghost](https://ircv3.net/specs/extensions/chghost)
    * [echo-message](https://ircv3.net/specs/extensions/echo-message)
    * [extended-join](https://ircv3.net/specs/extensions/extended-join)
    * [invite-notify](https://ircv3.net/specs/extensions/invite-notify)
    * [labeled-response](https://ircv3.net/specs/extensions/labeled-response)
    * [message-tags](https://ircv3.net/specs/extensions/message-tags)
    * [Monitor](https://ircv3.net/specs/extensions/monitor)
    * [msgid](https://ircv3.net/specs/extensions/message-ids)
    * [multi-prefix](https://ircv3.net/specs/extensions/multi-prefix)
    * [read-marker](https://ircv3.net/specs/extensions/read-marker)
    * [sasl-3.1](https://ircv3.net/specs/extensions/sasl-3.1)
    * [server-time](https://ircv3.net/specs/extensions/server-time)
    * [setname](https://ircv3.net/specs/extensions/setname.html)
    * [Standard Replies](https://ircv3.net/specs/extensions/standard-replies)
    * [userhost-in-names](https://ircv3.net/specs/extensions/userhost-in-names)
    * [`UTF8ONLY`](https://ircv3.net/specs/extensions/utf8-only)
    * [`WHOX`](https://ircv3.net/specs/extensions/whox)
    * [`soju.im/bouncer-networks`](https://codeberg.org/emersion/soju/src/branch/master/doc/ext/bouncer-networks.md)
* SASL support
* DCC Send
* Keyboard shortcuts
* Auto-completion for nicknames, commands, and channels
* Notifications support
* Multiple channels at the same time across servers
* Command bar for for quick actions
* [Custom themes](https://themes.halloy.chat)
* Portable mode

## Contributing
Halloy is free and open source. You can find the source code as well as report issues and feature requests on [GitHub](https://github.com/squidowl/halloy).
